<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="mainwindow.ui" line="26"/>
        <location filename="ui_mainwindow.h" line="890"/>
        <source>User Manager</source>
        <translation>Gerenciador de Usuários</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="62"/>
        <location filename="ui_mainwindow.h" line="947"/>
        <source>Administration</source>
        <translation>Administração</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="65"/>
        <location filename="ui_mainwindow.h" line="948"/>
        <source>Add a new user</source>
        <translation>Adicionar um novo usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="105"/>
        <location filename="ui_mainwindow.h" line="891"/>
        <source>Add User Account</source>
        <translation>Adicionar Conta de Usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="132"/>
        <location filename="ui_mainwindow.h" line="893"/>
        <source>Reenter password for new user</source>
        <translation>Informe a senha novamente para o novo usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="141"/>
        <location filename="ui_mainwindow.h" line="896"/>
        <source>confirm password</source>
        <translation>Confirme a Senha</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="154"/>
        <location filename="mainwindow.ui" line="1118"/>
        <location filename="ui_mainwindow.h" line="898"/>
        <location filename="ui_mainwindow.h" line="1034"/>
        <source>Username of new user</source>
        <translation>Nomedeusuario do novo usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <location filename="ui_mainwindow.h" line="900"/>
        <source>User login name:</source>
        <translation>Nome de autenticação do usuário:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="170"/>
        <location filename="mainwindow.ui" line="416"/>
        <location filename="mainwindow.ui" line="1134"/>
        <location filename="ui_mainwindow.h" line="902"/>
        <location filename="ui_mainwindow.h" line="936"/>
        <location filename="ui_mainwindow.h" line="1038"/>
        <source>Enter username of new user</source>
        <translation>Informe o nomedeusuario do novo usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="176"/>
        <location filename="mainwindow.ui" line="422"/>
        <location filename="ui_mainwindow.h" line="905"/>
        <location filename="ui_mainwindow.h" line="939"/>
        <source>username</source>
        <translation>nomedeusuario</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="189"/>
        <location filename="mainwindow.ui" line="227"/>
        <location filename="ui_mainwindow.h" line="907"/>
        <location filename="ui_mainwindow.h" line="916"/>
        <source>Password for new user</source>
        <translation>Senha para o novo usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <location filename="ui_mainwindow.h" line="909"/>
        <source>User password:</source>
        <translation>Senha do usuário:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="205"/>
        <location filename="ui_mainwindow.h" line="911"/>
        <source>Enter password for new user</source>
        <translation>Informe a senha do novo usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="214"/>
        <location filename="ui_mainwindow.h" line="914"/>
        <source>password</source>
        <translation>senha</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="230"/>
        <location filename="ui_mainwindow.h" line="918"/>
        <source>Confirm user password:</source>
        <translation>Confirme a senha do usuário:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="262"/>
        <location filename="ui_mainwindow.h" line="919"/>
        <source>Delete User Account</source>
        <translation>Remover Conta de Usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="305"/>
        <location filename="ui_mainwindow.h" line="921"/>
        <source>Select user</source>
        <translation>Selecione o usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <location filename="mainwindow.ui" line="1209"/>
        <location filename="mainwindow.ui" line="1222"/>
        <location filename="mainwindow.ui" line="1346"/>
        <location filename="mainwindow.ui" line="1368"/>
        <location filename="ui_mainwindow.h" line="925"/>
        <location filename="ui_mainwindow.h" line="1044"/>
        <location filename="ui_mainwindow.h" line="1047"/>
        <location filename="ui_mainwindow.h" line="1053"/>
        <location filename="ui_mainwindow.h" line="1057"/>
        <source>Select user to delete</source>
        <translation>Selecione o usuário para remover</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="330"/>
        <location filename="ui_mainwindow.h" line="927"/>
        <source>User to delete:</source>
        <translation>Usuário a remover:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="343"/>
        <location filename="ui_mainwindow.h" line="929"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Apagar também o diretório home/pasta pessoal do usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="346"/>
        <location filename="ui_mainwindow.h" line="931"/>
        <source>Delete user home directory</source>
        <translation>Apagar o diretório home/pasta pessoal do usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="359"/>
        <location filename="ui_mainwindow.h" line="932"/>
        <source>Rename User Account</source>
        <translation>Renomear a Conta de Usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <location filename="mainwindow.ui" line="483"/>
        <location filename="ui_mainwindow.h" line="933"/>
        <location filename="ui_mainwindow.h" line="945"/>
        <source>Select user to modify:</source>
        <translation>Selecione o usuário para modificar:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="403"/>
        <location filename="ui_mainwindow.h" line="934"/>
        <source>New user name:</source>
        <translation>Nome do novo usuário:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="432"/>
        <location filename="ui_mainwindow.h" line="940"/>
        <source>Change User Password</source>
        <translation>Alterar a Senha do Usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="447"/>
        <location filename="ui_mainwindow.h" line="942"/>
        <source>new password</source>
        <translation>Nova senha</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <location filename="ui_mainwindow.h" line="943"/>
        <source>Confirm new password:</source>
        <translation>Confirme a nova senha:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="470"/>
        <location filename="ui_mainwindow.h" line="944"/>
        <source>confirm new password</source>
        <translation>confirme a nova senha</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="496"/>
        <location filename="ui_mainwindow.h" line="946"/>
        <source>New user password:</source>
        <translation>Nova senha de usuário:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="527"/>
        <location filename="ui_mainwindow.h" line="977"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="530"/>
        <location filename="ui_mainwindow.h" line="978"/>
        <source>Repair a user configuration</source>
        <translation>Reparar uma configuração de usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="564"/>
        <location filename="mainwindow.ui" line="1271"/>
        <location filename="ui_mainwindow.h" line="949"/>
        <location filename="ui_mainwindow.h" line="1051"/>
        <source>Modify User Account</source>
        <translation>Modificar a Conta de Usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <location filename="mainwindow.ui" line="592"/>
        <location filename="ui_mainwindow.h" line="951"/>
        <location filename="ui_mainwindow.h" line="955"/>
        <source>Select user to repair</source>
        <translation>Selecione o usuário para reparar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="579"/>
        <location filename="mainwindow.ui" line="1355"/>
        <location filename="ui_mainwindow.h" line="953"/>
        <location filename="ui_mainwindow.h" line="1055"/>
        <source>User to change:</source>
        <translation>Mudar de usuário :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <location filename="ui_mainwindow.h" line="957"/>
        <source>Restore Defaults</source>
        <translation>Restaurar Padrões</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="645"/>
        <location filename="ui_mainwindow.h" line="959"/>
        <source>Restore browser configs to antiX defaults</source>
        <translation>Restaure as configurações do navegador para os padrões do antiX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="651"/>
        <location filename="ui_mainwindow.h" line="964"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configurações do Mozilla (Iceweasel ou Firefox)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="654"/>
        <location filename="ui_mainwindow.h" line="965"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="661"/>
        <location filename="ui_mainwindow.h" line="967"/>
        <source>Restore group memberships to antiX defaults</source>
        <translation>Restaurar associações de grupos aos padrões do antiX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="667"/>
        <location filename="ui_mainwindow.h" line="972"/>
        <source>Group memberships</source>
        <translation>Membros do grupo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="670"/>
        <location filename="ui_mainwindow.h" line="973"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="680"/>
        <location filename="ui_mainwindow.h" line="974"/>
        <source>Change Autologin Settings</source>
        <translation>Alterar as Configurações de Autenticação/Acesso Automático</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="686"/>
        <location filename="ui_mainwindow.h" line="975"/>
        <source>Log in automatically</source>
        <translation>Faça a autenticação (login) automaticamente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="693"/>
        <location filename="ui_mainwindow.h" line="976"/>
        <source>Require password to log in</source>
        <translation>Requer senha para entrar na sessão</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="708"/>
        <location filename="ui_mainwindow.h" line="1031"/>
        <source>Copy/Sync</source>
        <translation>Copiar/Sincronizar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="735"/>
        <location filename="ui_mainwindow.h" line="979"/>
        <source>Copy Between Desktops</source>
        <translation>Copiar Entre as Áreas de Trabalho</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="762"/>
        <location filename="mainwindow.ui" line="829"/>
        <location filename="ui_mainwindow.h" line="981"/>
        <location filename="ui_mainwindow.h" line="995"/>
        <source>Select desktop to copy from</source>
        <translation>Selecione a área de trabalho para copiar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="775"/>
        <location filename="ui_mainwindow.h" line="984"/>
        <source>Select to only copy files</source>
        <translation>Selecione para apenas copiar arquivos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="778"/>
        <location filename="ui_mainwindow.h" line="986"/>
        <source>Copy only</source>
        <translation>Apenas copiar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="794"/>
        <location filename="mainwindow.ui" line="807"/>
        <location filename="ui_mainwindow.h" line="988"/>
        <location filename="ui_mainwindow.h" line="991"/>
        <source>Select desktop to copy to</source>
        <translation>Selecione a área de trabalho para onde copiar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="816"/>
        <location filename="ui_mainwindow.h" line="993"/>
        <source>Copy to:</source>
        <translation>Copiar para:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="838"/>
        <location filename="ui_mainwindow.h" line="997"/>
        <source>Copy from:</source>
        <translation>Copiar de:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="851"/>
        <location filename="ui_mainwindow.h" line="999"/>
        <source>Select to copy and then delete differences</source>
        <translation>Selecione para copiar e então apagar as diferenças</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="854"/>
        <location filename="ui_mainwindow.h" line="1001"/>
        <source>Sync</source>
        <translation>Sincronizar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="900"/>
        <location filename="ui_mainwindow.h" line="1004"/>
        <source>Select to copy/sync Shared</source>
        <translation>Selecione para copiar/sincronizar compartilhada (Shared)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="903"/>
        <location filename="ui_mainwindow.h" line="1006"/>
        <source>Shared folder</source>
        <translation>Pasta Compartilhada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="916"/>
        <location filename="ui_mainwindow.h" line="1008"/>
        <source>Select to copy/sync entire home</source>
        <translation>Selecione para copiar/sincronizar toda a pasta pessoal (home)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="919"/>
        <location filename="ui_mainwindow.h" line="1010"/>
        <source>Entire home</source>
        <translation>Toda a pasta pessoal (home)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <location filename="ui_mainwindow.h" line="1012"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Selecione para copiar/sincronizar a configuração do navegador</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="938"/>
        <location filename="ui_mainwindow.h" line="1014"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Configurações do Mozilla (Firefox ou Iceweasel)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="951"/>
        <location filename="ui_mainwindow.h" line="1016"/>
        <source>Select to copy/sync Documents</source>
        <translation>Selecione para copiar/sincronizar a pasta Documentos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="954"/>
        <location filename="ui_mainwindow.h" line="1018"/>
        <source>Documents folder</source>
        <translation>Pasta Documentos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="961"/>
        <location filename="ui_mainwindow.h" line="1019"/>
        <source>What to copy/sync:</source>
        <translation>O que copiar/sincronizar:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="977"/>
        <location filename="ui_mainwindow.h" line="1020"/>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1007"/>
        <location filename="mainwindow.ui" line="1023"/>
        <location filename="ui_mainwindow.h" line="1022"/>
        <location filename="ui_mainwindow.h" line="1025"/>
        <source>Status of the changes</source>
        <translation>Estado das alterações</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1026"/>
        <location filename="ui_mainwindow.h" line="1027"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1042"/>
        <location filename="ui_mainwindow.h" line="1029"/>
        <source>Progress of the changes</source>
        <translation>Progresso das alterações</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1079"/>
        <location filename="ui_mainwindow.h" line="1050"/>
        <source>Add/Remove Groups</source>
        <translation>Adicionar/Remover grupos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1091"/>
        <location filename="ui_mainwindow.h" line="1032"/>
        <source>Add Group</source>
        <translation>Adicionar Grupo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1121"/>
        <location filename="ui_mainwindow.h" line="1036"/>
        <source>Group name:</source>
        <translation>Nome do grupo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1140"/>
        <location filename="ui_mainwindow.h" line="1041"/>
        <source>groupname</source>
        <translation>nomedogrupo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1169"/>
        <location filename="ui_mainwindow.h" line="1042"/>
        <source>Delete Group</source>
        <translation>Apagar Grupo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1231"/>
        <location filename="ui_mainwindow.h" line="1049"/>
        <source>Group to delete:</source>
        <translation>Grupo para remover:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1259"/>
        <location filename="ui_mainwindow.h" line="1061"/>
        <source>Group Membership</source>
        <translation>Membros do Grupo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1375"/>
        <location filename="ui_mainwindow.h" line="1059"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>O usuário de grupos pertence a (altere os grupos marcando/desmarcando as caixas apropriadas):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1395"/>
        <location filename="ui_mainwindow.h" line="1060"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>* Por favor, verifique as suas seleções antes de aplicar, se você atribuir as associações de grupo erradas poderá quebrar seu sistema. Use a guia Reparar para restaurar as associações originais se você cometer algum erro.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1455"/>
        <location filename="ui_mainwindow.h" line="1063"/>
        <source>Apply any changes</source>
        <translation>Aplicar as alterações</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1458"/>
        <location filename="ui_mainwindow.h" line="1065"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1465"/>
        <location filename="ui_mainwindow.h" line="1066"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1472"/>
        <location filename="ui_mainwindow.h" line="1068"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar as alterações e sair</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1475"/>
        <location filename="ui_mainwindow.h" line="1070"/>
        <source>Close</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1482"/>
        <location filename="ui_mainwindow.h" line="1071"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1523"/>
        <location filename="ui_mainwindow.h" line="1074"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1526"/>
        <location filename="ui_mainwindow.h" line="1076"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1533"/>
        <location filename="ui_mainwindow.h" line="1077"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1540"/>
        <location filename="ui_mainwindow.h" line="1079"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1543"/>
        <location filename="ui_mainwindow.h" line="1081"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1550"/>
        <location filename="ui_mainwindow.h" line="1082"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="109"/>
        <location filename="mainwindow.cpp" line="141"/>
        <location filename="mainwindow.cpp" line="149"/>
        <location filename="mainwindow.cpp" line="162"/>
        <location filename="mainwindow.cpp" line="173"/>
        <location filename="mainwindow.cpp" line="182"/>
        <location filename="mainwindow.cpp" line="191"/>
        <location filename="mainwindow.cpp" line="617"/>
        <location filename="mainwindow.cpp" line="634"/>
        <location filename="mainwindow.cpp" line="665"/>
        <location filename="mainwindow.cpp" line="674"/>
        <location filename="mainwindow.cpp" line="819"/>
        <location filename="mainwindow.cpp" line="932"/>
        <source>none</source>
        <translation>nenhum</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="203"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>A configuração de usuário será reparada. Por favor, feche todos os outros aplicativos agora. Quando você concluir, saia da sessão ou reinicie. Você tem certeza de que quer reparar agora?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="225"/>
        <source>User group membership was restored.</source>
        <translation>A associação ao grupo de usuários foi restaurada.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation>As configurações do Mozilla foram redefinidas.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <location filename="mainwindow.cpp" line="248"/>
        <source>Autologin options</source>
        <translation>Opções de acesso automático</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="238"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>O acesso automático foi desativado para a conta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="249"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>O acesso automático foi ativado para  a conta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="261"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Você tem que especificar um destino para &apos;copiar para&apos;. Você não pode copiar para a área de trabalho da sessão.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Antes de copiar, feche todas os outros aplicativos. Certifique-se de que o destino de &apos;copiar para&apos; é suficientemente grande para receber todos os os arquivos que você está copiando. Copiar entre as áreas de trabalho pode sobrescrever ou apagar seus arquivos ou preferências na área de trabalho de destino. Você tem certeza de que quer continuar?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="290"/>
        <source>Synchronizing desktop...</source>
        <translation>Sincronizando a área de trabalho ...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="292"/>
        <source>Copying desktop...</source>
        <translation>Copiando a área de trabalho...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="313"/>
        <location filename="mainwindow.cpp" line="508"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>O nome de usuário tem que ter pelo menos 2 caracteres. Escolha um nome mais longo antes de continuar.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="317"/>
        <location filename="mainwindow.cpp" line="512"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>O nome de usuário tem que estar em letras 
minúsculas e não pode conter caracteres 
especiais ou espaços. 
Por favor, escolha outro nome de usuário 
antes de continuar.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="326"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Desculpe, este nome está em uso. Por favor, insira um nome diferente.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="331"/>
        <location filename="mainwindow.cpp" line="366"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>As senhas não coincidem. Por favor, tente novamente.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="336"/>
        <location filename="mainwindow.cpp" line="371"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>A senha tem que ter pelo menos 2 caracteres. Por favor, insira uma senha mais longa antes de continuar.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="353"/>
        <source>The user was added ok.</source>
        <translation>O usuário foi adicionado corretamente.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="357"/>
        <source>Failed to add the user.</source>
        <translation>Falha ao adicionar o usuário.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="385"/>
        <source>Password successfully changed.</source>
        <translation>A senha foi alterada com sucesso.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="389"/>
        <source>Failed to change password.</source>
        <translation>Falha na alteração da senha.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="395"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Esta ação não pode ser desfeita. Você tem certeza de que pretende apagar o usuário %1?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="408"/>
        <source>The user has been deleted.</source>
        <translation>O usuário foi apagado.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="411"/>
        <source>Failed to delete the user.</source>
        <translation>Falha ao apagar o usuário.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="425"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>O nome de grupo tem que ter pelo menos 2 caracteres. Por favor, escolha um nome mais longo antes de continuar.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="429"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>O nome de grupo tem que estar em letras 
minúsculas e não pode conter caracteres 
especiais ou espaços.
Por favor, escolha outro nome antes de 
continuar.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="438"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Desculpe, esse nome de grupo já existe. Por favor, insira um nome diferente.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <source>The system group was added ok.</source>
        <translation>O grupo foi adicionado.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="448"/>
        <source>Failed to add the system group.</source>
        <translation>Falha ao adicionar o grupo do sistema.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="451"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Esta ação não poderá ser desfeita. Você tem certeza de que pretende apagar o grupo %1?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="458"/>
        <source>The group has been deleted.</source>
        <translation>O grupo foi apagado.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="461"/>
        <source>Failed to delete the group.</source>
        <translation>Falha ao apagar o grupo.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="483"/>
        <source>The changes have been applied.</source>
        <translation>As alterações foram aplicadas.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="486"/>
        <source>Failed to apply group changes</source>
        <translation>Falha ao aplicar as alterações do grupo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>The selected user name is currently in use.</source>
        <translation>O nome de usuário selecionado está em uso.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="500"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Para renomear este usuário, saia da sessão e volte a entrar com outra conta de usuário.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="521"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Desculpe, este nome já existe em seu sistema. Por favor, insira um nome diferente.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Falha ao renomear o usuário. Por favor, certifique-se de que o usuário não esteja acessando a sessão; pode ser necessário reiniciar.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="543"/>
        <source>The user was renamed.</source>
        <translation>O usuário foi renomeado.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="556"/>
        <location filename="mainwindow.cpp" line="585"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sincronizando a área de trabalho... concluído.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="558"/>
        <location filename="mainwindow.cpp" line="587"/>
        <source>Copying desktop...ok</source>
        <translation>Copiando a área de trabalho ... concluído.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="591"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sincronizando a área de trabalho ... falhou</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="593"/>
        <source>Copying desktop...failed</source>
        <translation>Copiando a área de trabalho... falhou </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="611"/>
        <location filename="mainwindow.cpp" line="871"/>
        <location filename="mainwindow.cpp" line="879"/>
        <source>browse...</source>
        <translation>percorrer...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="782"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="783"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="784"/>
        <source>Simple user configuration for antiX Linux</source>
        <translation>Configurações simples de usuários do antiX</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="786"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="787"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="802"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="872"/>
        <source>Select folder to copy to</source>
        <translation>Selecione a pasta para onde copiar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="32"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="about.cpp" line="33"/>
        <location filename="about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="main.cpp" line="41"/>
        <source>You must run this program as root.</source>
        <translation>Você tem que executar este programa como root (administrador).</translation>
    </message>
</context>
</TS>